==> editable-grid-2.0.3.tgz: package/lib/demo-bootstrap.js <==
var $ = require('jquery'),
    datepicker = require('date-selector'),
    demoCreator = require('./demos/demoCreator'),
    demoAddRow = require('./demos/demoAddRow'),
    demoAddRowAdvanced = require('./demos/demoAddRowAdvanced'),
    demoBasicTableRender = require('./demos/demoBasicTableRender'),
    demoBasicTreeTableRender = require('./demos/demoBasicTreeTableRender'),
    demoCellFormatting = require('./demos/demoCellFormatting'),
    demoColumnSorting = require('./demos/demoColumnSorting'),
    demoEditableCells = require('./demos/demoEditableCells'),
    demoFixedHeightTableRender = require('./demos/demoFixedHeightTableRender'),
    demoLinks = require('./demos/demoLinks'),
    demoRowDeletion = require('./demos/demoRowDeletion'),
    demoRowSelection = require('./demos/demoRowSelection'),
    demoTotalRow = require('./demos/demoTotalRow'),
    demoNoBorders = require('./demos/demoNoBorders'),
    demoCheckboxColumn = require('./demos/demoCheckboxColumn');


$(function () {

    datepicker();

    demoCreator(demoNoBorders);
    demoCreator(demoBasicTableRender);
    demoCreator(demoBasicTreeTableRender);
    demoCreator(demoCellFormatting);
    demoCreator(demoLinks);
    demoCreator(demoColumnSorting);
    demoCreator(demoTotalRow);
    demoCreator(demoRowSelection);
    demoCreator(demoFixedHeightTableRender);
    demoCreator(demoAddRow);
    demoCreator(demoAddRowAdvanced);
    demoCreator(demoEditableCells);
    demoCreator(demoRowDeletion);
    demoCreator(demoCheckboxColumn);

});

==> editable-grid-2.0.4.tgz: package/lib/demo-bootstrap.js <==
var $ = require('jquery'),
    datepicker = require('date-selector'),
    demoCreator = require('./demos/demoCreator'),
    demoAddRow = require('./demos/demoAddRow'),
    demoAddRowAdvanced = require('./demos/demoAddRowAdvanced'),
    demoBasicTableRender = require('./demos/demoBasicTableRender'),
    demoBasicTreeTableRender = require('./demos/demoBasicTreeTableRender'),
    demoCellFormatting = require('./demos/demoCellFormatting'),
    demoColumnSorting = require('./demos/demoColumnSorting'),
    demoEditableCells = require('./demos/demoEditableCells'),
    demoFixedHeightTableRender = require('./demos/demoFixedHeightTableRender'),
    demoLinks = require('./demos/demoLinks'),
    demoRowDeletion = require('./demos/demoRowDeletion'),
    demoRowSelection = require('./demos/demoRowSelection'),
    demoTotalRow = require('./demos/demoTotalRow'),
    demoNoBorders = require('./demos/demoNoBorders'),
    demoCheckboxColumn = require('./demos/demoCheckboxColumn'),
    demoCellClassesRender = require('./demos/demoCellClassesRender');


$(function () {

    datepicker();

    demoCreator(demoNoBorders);
    demoCreator(demoBasicTableRender);
    demoCreator(demoBasicTreeTableRender);
    demoCreator(demoCellFormatting);
    demoCreator(demoLinks);
    demoCreator(demoColumnSorting);
    demoCreator(demoTotalRow);
    demoCreator(demoRowSelection);
    demoCreator(demoFixedHeightTableRender);
    demoCreator(demoAddRow);
    demoCreator(demoAddRowAdvanced);
    demoCreator(demoEditableCells);
    demoCreator(demoRowDeletion);
    demoCreator(demoCheckboxColumn);
    demoCreator(demoCellClassesRender);

});
